Front Matter — dogpile.core 0.3.0 documentation

### Navigation

- index
- next |
- previous |
- dogpile.core 0.3.0 documentation »

# Front Matter

Information about the dogpile.core project.

## Project Homepage

dogpile.core is hosted on Bitbucket - the lead project page is at https://bitbucket.org/zzzeek/dogpile.core. Source code is tracked here using Mercurial.

Releases and project status are available on Pypi at http://pypi.python.org/pypi/dogpile.core.

The most recent published version of this documentation should be at http://dogpilecore.readthedocs.org.

## Installation

Install released versions of dogpile.core from the Python package index with pip or a similar tool:

    pip install dogpile.core

Installation via source distribution is via the `setup.py` script:

    python setup.py install

## Community

dogpile.core is developed by Mike Bayer, and is loosely associated with the Pylons Project. As usage of dogpile.core and dogpile.cache increases, it is anticipated that the Pylons mailing list and IRC channel will become the primary channels for support.

## Bugs

Bugs and feature enhancements to dogpile.core should be reported on the Bitbucket issue tracker. If you’re not sure that a particular issue is specific to either dogpile.cache or dogpile.core, posting to the dogpile.cache issue tracker is likely the better place to post first, but it’s not critical either way.

- dogpile.cache issue tracker (post here if unsure)
- dogpile.core issue tracker

### Navigation

- index
- next |
- previous |
- dogpile.core 0.3.0 documentation »